=========
geo_calcs
=========


.. image:: https://img.shields.io/pypi/v/geo_calcs.svg
        :target: https://pypi.python.org/pypi/geo_calcs

.. image:: https://img.shields.io/travis/drew026/geo_calcs.svg
        :target: https://travis-ci.com/drew026/geo_calcs

.. image:: https://readthedocs.org/projects/geo-calcs/badge/?version=latest
        :target: https://geo-calcs.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A Python package for caclulations and visualizations in geological sciences.


* Free software: MIT license
* Documentation: https://geo-calcs.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
